/**
 * Layout component that queries for data
 * with Gatsby's useStaticQuery component
 *
 * See: https://www.gatsbyjs.com/docs/how-to/querying-data/use-static-query/
 */

import * as React from 'react';
import { useStaticQuery, graphql, withPrefix } from 'gatsby';

import Header from './header';
import TableOfContents from './toc';
import Sidebar from './sidebar';
import Footer from './footer';
import { useMobileNavigation } from '../hooks/useMobileNavigation';
import { useNavigation } from '../hooks/useNavigation';
import Breadcrumbs from './breadcrumbs';

const Layout = ({ children, location, currentSlug, sidebar = true }) => {
  const slug = currentSlug ?? '/';
  const isFrontPage = slug === '/';
  const [isMobileNavOpen, toggleMobileNav] = useMobileNavigation();
  const treeData = useNavigation();
  const { site } = useStaticQuery(graphql`
    query SiteTitleQuery {
      site {
        siteMetadata {
          title,
          themeConfig {
            useLegacyUrls
          }
        }
      }
    }
  `);

  const { title, themeConfig: { useLegacyUrls } } = site.siteMetadata;

  let currentNavigationBranch = `/${slug.split('/')[0]}`;
  if (useLegacyUrls) {
    currentNavigationBranch = slug === '/' ? slug : `/${slug.split('/')[0]}/index.html`;
  }

  return (
    <div className="min-h-screen flex flex-col pt-16 md:pt-0">
      <Header siteTitle={title || 'Title'} isMobileNavOpen={isMobileNavOpen} toggleMobileNav={toggleMobileNav} />
      <div className="relative mx-auto flex w-full max-w-screen-2xl justify-center sm:px-2 lg:px-8 xl:px-12">
        {sidebar && (<Sidebar branch={currentNavigationBranch} isMobileNavOpen={isMobileNavOpen} treeData={treeData} />)}
        <div className="flex-1 container max-w-3xl px-4 py-16 lg:max-w-none lg:pl-8 lg:pr-0 xl:px-16">
          {!isFrontPage && <Breadcrumbs treeData={treeData} currentPath={location.pathname} />}
          <main id="content">{children}</main>
        </div>
        {!isFrontPage && (<TableOfContents />)}
      </div>
      <Footer>
        <div className="flex justify-center">
          <div className="px-6">
            platformOS DocsKit &copy; {new Date().getFullYear()} &mdash; powered by <a href="https://platformos.com" target="_blank" rel="noreferrer" className="underline font-bold">platformOS</a> &mdash; built with <a href="https://gatsby.com" target="_blank" rel="noreferrer">Gatsby</a>

          </div>
        </div>
      </Footer>
    </div>
  );
};

export default Layout;
